<?php

namespace Drupal\gsap\Form;

use Drupal\Core\Form\ConfigFormBase;
use Drupal\Core\Form\FormStateInterface;

/**
 * Admin settings for GSAP.
 *
 * @package Drupal\gsap\Form
 */
class Admin extends ConfigFormBase {

  /**
   * {@inheritdoc}
   */
  protected function getEditableConfigNames() {
    return ['gsap.settings'];
  }

  /**
   * {@inheritdoc}
   */
  public function getFormId() {
    return 'gsap_admin';
  }

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state) {
    $config = $this->config('gsap.settings');
    $form = parent::buildForm($form, $form_state);

    $form['libs'] = [
      '#title' => $this->t('Libraries to Include.'),
      '#description' => $this->t('Select the plugins to include as libraries. These will be added to every page.'),
      '#type' => 'checkboxes',
      '#required' => TRUE,
      '#default_value' => $config->get('libs') ?? [],
      '#options' => [
        'flip' => $this->t('Flip'),
        'scrolltrigger' => $this->t('ScrollTrigger'),
        'observer' => $this->t('Observer'),
        'scrollto' => $this->t('ScrollTo'),
        'draggable' => $this->t('Draggable'),
        'easel' => $this->t('Easel'),
        'motionpath' => $this->t('MotionPath'),
        'pixi' => $this->t('Pixi'),
        'text' => $this->t('Text'),
      ],
    ];

    return $form;
  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {
    $libraries = array_values(array_filter($form_state->getValue('libs')));
    $this->configFactory->getEditable('gsap.settings')
      ->set('libs', $libraries)
      ->save();

    parent::submitForm($form, $form_state);
  }

}
